#
# Example of a GDELT 2.0 record.
#
example_record = {
    "_id": 1034618754,
    "Day": 20210318,
    "MonthYear": 202103,
    "Year": 2021,
    "FractionDate": 2021.2137,
    "Actor1Code": "COP",
    "Actor1Name": "POLICE",
    "Actor1CountryCode": "",
    "Actor1KnownGroupCode": "",
    "Actor1EthnicCode": "",
    "Actor1Religion1Code": "",
    "Actor1Religion2Code": "",
    "Actor1Type1Code": "COP",
    "Actor1Type2Code": "",
    "Actor1Type3Code": "",
    "Actor2Code": "JUD",
    "Actor2Name": "PROSECUTOR",
    "Actor2CountryCode": "",
    "Actor2KnownGroupCode": "",
    "Actor2EthnicCode": "",
    "Actor2Religion1Code": "",
    "Actor2Religion2Code": "",
    "Actor2Type1Code": "JUD",
    "Actor2Type2Code": "",
    "Actor2Type3Code": "",
    "IsRootEvent": 0,
    "EventCode": "010",
    "EventBaseCode": "010",
    "EventRootCode": "01",
    "QuadClass": 1,
    "GoldsteinScale": 0,
    "NumMentions": 54,
    "NumSources": 9,
    "NumArticles": 54,
    "AvgTone": -10.4477611940299,
    "Actor1Geo_Type": 4,
    "Actor1Geo_Fullname": "London, London, City of, United Kingdom",
    "Actor1Geo_CountryCode": "UK",
    "Actor1Geo_ADM1Code": "UKH9",
    "Actor1Geo_ADM2Code": "40110",
    "Actor1Geo_Lat": 51.5,
    "Actor1Geo_Long": -0.116667,
    "Actor1Geo_FeatureID": "-2601889",
    "Actor2Geo_Type": "4",
    "Actor2Geo_Fullname": "London, London, City of, United Kingdom",
    "Actor2Geo_CountryCode": "UK",
    "Actor2Geo_ADM1Code": "UKH9",
    "Actor2Geo_ADM2Code": "40110",
    "Actor2Geo_Lat": 51.5,
    "Actor2Geo_Long": -0.116667,
    "Actor2Geo_FeatureID": "-2601889",
    "ActionGeo_Type": 4,
    "ActionGeo_Fullname": "London, London, City of, United Kingdom",
    "ActionGeo_CountryCode": "UK",
    "ActionGeo_ADM1Code": "UKH9",
    "ActionGeo_ADM2Code": "40110",
    "ActionGeo_Lat": 51.5,
    "ActionGeo_Long": -0.116667,
    "ActionGeo_FeatureID": "-2601889", "DATEADDED": "20220318143000",
     "SOURCEURL": "https://www.lancashiretelegraph.co.uk/news/20003985.depraved-sex-predator-jailed-42-years-murder-violent-spree/",
}
